/*
 * A context resource offering support for opening files.
 *
 * Copyright (C) 2021, 2022, 2023 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <fsserver/opener_context_object_interface.h>
#include <fsserver/simple_pager.h>



/* Forward declaration. */

class OpenerResource;



/* Support for indicating files to be opened. */

class OpenerContextResource : public SimplePager, public OpenerContextObject
{
protected:
    OpenerResource *_opener;

public:
    explicit OpenerContextResource(OpenerResource *opener, Memory *memory=NULL);

    /* Server details. */

    ipc_server_default_config_type config();

    void *interface()
    { return static_cast<OpenerContextObject *>(this); }

    /* Opener context interface methods. */

    long mkdir(sys_mode_t mode);

    long open(flags_t flags, offset_t *size, l4_cap_idx_t *file,
              object_flags_t *object_flags);

    long remove();

    long rename();

    long stat();

    /* Pager/dataspace methods. */

    long map(offset_t offset, map_address_t hot_spot, map_flags_t flags,
             l4_snd_fpage_t *region)
    { return SimplePager::map(offset, hot_spot, flags, region); }

    long info(offset_t *size, map_flags_t *flags)
    { return SimplePager::info(size, flags); }
};

// vim: tabstop=4 expandtab shiftwidth=4
